#
# spec file for package libkdumpfile
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Begin compatibility cruft
#

%{!?make_install:%define make_install make install DESTDIR=%{?buildroot}}

%if 0%{!?have_snappy:1}
%if 0%{?suse_version} >= 1310
%define have_snappy 1
%else
%define have_snappy 0
%endif
%endif

# There was no Python single-spec before SLE15
%if %{defined pythons}
%define new_python_macros 1
%else
%define new_python_macros 0
%define python_module() python-%{**} python3-%{**}
%define ifpython2 %if 0
%define python_build python setup.py build
%define python_install python setup.py install --skip-build --root %{?buildroot}
%define python3_build python3 setup.py build
%define python3_install python3 setup.py install --skip-build --root %{?buildroot}
%endif

#
# End compatibility cruft

%define oldpython python

Name:           libkdumpfile
Version:        0.4.1
Release:        150400.3.3.2
%if "%name" == "libkdumpfile"
Summary:        Kernel dump file access library
License:        GPL-2.0-or-later OR LGPL-3.0-or-later
Group:          Development/Languages/Python
%else
Summary:        Python interface for libkdumpfile
License:        GPL-2.0-or-later OR LGPL-3.0-or-later
Group:          Development/Languages/Python
%endif
URL:            https://github.com/ptesarik/libkdumpfile
Source:         https://github.com/ptesarik/libkdumpfile/releases/download/v%{version}/%{name}-%{version}.tar.bz2
Patch1:         diskdump-Separate-init_private-from-open_common.patch
Patch2:         diskdump-Support-flattened-diskdump-format.patch
Patch3:         diskdump-Map-compressed-data-directly-from-file-cach.patch
Patch4:         diskdump-Remove-page_size-override.patch
Patch5:         diskdump-Directly-map-buffers-from-flattened-file-ca.patch
Patch6:         diskdump-Add-struct-mdf_flatmap-to-hold-flattened-fo.patch
Patch7:         Remove-references-to-diskdump-private-data-from-flat.patch
Patch8:         flatmap-Move-flatmap-routines-to-flatmap.c.patch
Patch9:         diskdump-Always-allocate-a-flattened-offset-map.patch
Patch10:        diskdump-Support-partially-rearranged-file-sets.patch
Patch11:        elfdump-Support-makedumpfile-flattened-dumps.patch
Patch12:        flatmap-Allow-to-use-the-flatmap-API-with-non-flatte.patch
Patch13:        flatmap-Initialize-flatmap-offsets-only-once.patch
Patch14:        Clean-up-format-data-after-a-failed-probe.patch
Patch15:        diskdump-Delay-private-data-initialization.patch
Patch16:        Implement-zstd-compression-for-diskdump.patch
BuildRequires:  libzstd-devel
BuildRequires:  lzo-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} < 1030
BuildRequires:  binutils
%else
BuildRequires:  binutils-devel
%endif
BuildRequires:  %{python_module devel}
%if %{have_snappy}
BuildRequires:  snappy-devel
%endif
%ifpython2
Provides:       %{oldpython}-libaddrxlat = %{version}-%{release}
Obsoletes:      %{oldpython}-libaddrxlat < %{version}-%{release}
%endif

%if %new_python_macros
%python_subpackages
%endif

%description
%if "%name" == "libkdumpfile"
A library that provides an abstraction layer for reading kernel dump
core files.  It supports different kernel dump core formats, virtual
to physical translation, Xen mappings and more.
%else
This package contains all necessary python modules to use libkdumpfile via
the Python interpreter.
%endif

%if !%new_python_macros

%package -n python2-libkdumpfile
Summary:        Python interface for libkdumpfile
Group:          Development/Languages/Python
Provides:       python-libkdumpfile = %{version}-%{release}
Obsoletes:      python-libkdumpfile < %{version}-%{release}
Provides:       python-libaddrxlat = %{version}-%{release}
Obsoletes:      python-libaddrxlat < %{version}-%{release}

%description -n python2-libkdumpfile
This package contains all necessary python modules to use libkdumpfile via
the Python interpreter.

%package -n python3-libkdumpfile
Summary:        Python interface for libkdumpfile
Group:          Development/Languages/Python

%description -n python3-libkdumpfile
This package contains all necessary python modules to use libkdumpfile via
the Python interpreter.

%endif

%package -n %{name}-devel
Summary:        Include files and libraries for libkdumpfile development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libkdumpfile9 = %{version}

%description -n %{name}-devel
This package contains all necessary include files and libraries needed
to develop applications that require libkdumpfile.

%package -n libkdumpfile9
Summary:        Kernel dump file access library
Group:          System/Libraries

%description -n libkdumpfile9
A library that provides an abstraction layer for reading kernel dump
core files.  It supports different kernel dump core formats, virtual
to physical translation, Xen mappings and more.

This package contains the libkdumpfile library.

%package -n libaddrxlat2
Summary:        Address translation library used primarily by libkdumpfile
Group:          System/Libraries

%description -n libaddrxlat2
A library that provides an abstraction layer for translating addresses
between address spaces (i.e. physical vs virtual).

This package contains the libaddrxlat library.

%package -n libaddrxlat-devel
Summary:        Include files and libraries for libaddrxlat development
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libaddrxlat2 = %{version}

%description -n libaddrxlat-devel
This package contains all necessary include files and libraries needed
to develop applications that require libaddrxlat.

# Compatibility cruft
# there is no %%license prior to SLE12
%if %{undefined _defaultlicensedir}
%define license %doc
%else
# filesystem before SLE12 SP3 lacks /usr/share/licenses
%if 0%(test ! -d %{_defaultlicensedir} && echo 1)
%define _defaultlicensedir %{_defaultdocdir}
%endif
%endif
# End of compatibility cruft

%prep
%setup -q
%autopatch -p1

# Avoid autotools recheck after patching config*
touch aclocal.m4 Makefile.in config.h.in configure

%build
%configure --disable-static --without-python
make %{?_smp_mflags}
cd python
%if %new_python_macros
%{python_expand # Build for each Python version
rm -f setup.cfg
make setup.cfg DESTDIR=%{?buildroot} pyexecdir=%{$python_sitearch}
%$python_build
}
%else
make setup.cfg DESTDIR=%{?buildroot} pyexecdir=%{python_sitearch}
%python_build
rm -f setup.cfg
make setup.cfg DESTDIR=%{?buildroot} pyexecdir=%{python3_sitearch}
%python3_build
%endif

%install
%make_install
cd python
%python_install
%if !%new_python_macros
%python3_install
%endif

# Do not install example code
rm -v %{?buildroot}%{_bindir}/dumpattr
rm -v %{?buildroot}%{_bindir}/listxendoms
rm -v %{?buildroot}%{_bindir}/showxlat
# Remove Libtool files
rm -v %{?buildroot}%{_libdir}/libkdumpfile.la
rm -v %{?buildroot}%{_libdir}/libaddrxlat.la
%if %new_python_macros
%{python_expand # Libtool files for extension modules
rm -v %{?buildroot}%{$python_sitearch}/_kdumpfile*.la
rm -v %{?buildroot}%{$python_sitearch}/_addrxlat*.la
}
%else
rm -v %{?buildroot}%{python_sitearch}/_kdumpfile*.la
rm -v %{?buildroot}%{python_sitearch}/_addrxlat*.la
rm -v %{?buildroot}%{python3_sitearch}/_kdumpfile*.la
rm -v %{?buildroot}%{python3_sitearch}/_addrxlat*.la
%endif

%post -n libkdumpfile9 -p /sbin/ldconfig

%post -n libaddrxlat2 -p /sbin/ldconfig

%postun -n libkdumpfile9 -p /sbin/ldconfig

%postun -n libaddrxlat2 -p /sbin/ldconfig

%files -n libkdumpfile9
%defattr(-,root,root)
%{_libdir}/libkdumpfile.so.*
%license COPYING COPYING.GPLv2 COPYING.GPLv3 COPYING.LGPLv3
%doc README.md NEWS

%files -n libkdumpfile-devel
%defattr(-,root,root)
%{_includedir}/libkdumpfile/kdumpfile.h
%{_libdir}/libkdumpfile.so
%{_libdir}/pkgconfig/libkdumpfile.pc

%files -n libaddrxlat2
%defattr(-,root,root)
%{_libdir}/libaddrxlat.so.*
%license COPYING COPYING.GPLv2 COPYING.GPLv3 COPYING.LGPLv3
%doc README.md NEWS

%files -n libaddrxlat-devel
%defattr(-,root,root)
%dir %{_includedir}/libkdumpfile
%{_includedir}/libkdumpfile/addrxlat.h
%{_libdir}/libaddrxlat.so
%{_libdir}/pkgconfig/libaddrxlat.pc

%if %new_python_macros

%files %{python_files}
%defattr(-,root,root)
%{python_sitearch}/*

%else

%files -n python2-libkdumpfile
%defattr(-,root,root)
%{python_sitearch}/*

%files -n python3-libkdumpfile
%defattr(-,root,root)
%{python3_sitearch}/*

%endif

%changelog
* Fri Oct 11 2024 petr.tesarik@suse.com
- Implement-zstd-compression-for-diskdump.patch: support for zstd
  compression (bsc#1231429).
* Wed Oct  9 2024 petr.tesarik@suse.com
- Add support for flattened dump files (bsc#1223399):
  * diskdump-Separate-init_private-from-open_common.patch
  * diskdump-Support-flattened-diskdump-format.patch
  * diskdump-Map-compressed-data-directly-from-file-cach.patch
  * diskdump-Remove-page_size-override.patch
  * diskdump-Directly-map-buffers-from-flattened-file-ca.patch
  * diskdump-Add-struct-mdf_flatmap-to-hold-flattened-fo.patch
  * Remove-references-to-diskdump-private-data-from-flat.patch
  * flatmap-Move-flatmap-routines-to-flatmap.c.patch
  * diskdump-Always-allocate-a-flattened-offset-map.patch
  * diskdump-Support-partially-rearranged-file-sets.patch
  * elfdump-Support-makedumpfile-flattened-dumps.patch
  * flatmap-Allow-to-use-the-flatmap-API-with-non-flatte.patch
  * flatmap-Initialize-flatmap-offsets-only-once.patch
  * Clean-up-format-data-after-a-failed-probe.patch
  * diskdump-Delay-private-data-initialization.patch
* Thu Nov  4 2021 ptesarik@suse.com
- upgrade to libkdumpfile-0.4.1
  * Support Linux on AArch64
  * Support for x86 Secure Memory Encryption
  * Clean up vmcoreinfo string API
  * Expose mmap and read cache statistics
- Drop patches that are upstream:
  * libkdumpfile-use-python-distutils.patch
  * libkdumpfile-uninstall-using-distutils.patch
  * libkdumpfile-honour-DESTDIR.patch
  * libkdumpfile-move-python-setup-command-options.patch
  * libkdumpfile-python-includedir.patch
* Fri Feb 19 2021 ptesarik@suse.com
- Fix build for openSUSE:Factory.
* Sun Sep 27 2020 ptesarik@suse.com
- Switch to Python distutils:
  * libkdumpfile-use-python-distutils.patch
  * libkdumpfile-uninstall-using-distutils.patch
  * libkdumpfile-honour-DESTDIR.patch
  * libkdumpfile-move-python-setup-command-options.patch
  * libkdumpfile-python-includedir.patch
- Merge python-libaddrxlat into python-libkdumpfile.
- Build both Python2 and Python3 packages.
* Tue Sep 22 2020 ptesarik@suse.com
- upgrade to libkdumpfile-0.4.0
  * 5-level paging for x86-64
  * bitmap and blob attributes
  * kASLR support for Linux kernels
  * address translation speed-ups
  * many bugfixes
- Drop fix-build-with-recent-glibc.patch (now upstream).
* Tue Apr 28 2020 ptesarik@suse.com
- Mark COPYING* files with %%license.
* Tue Apr  9 2019 christophe@krop.fr
- Add fix-build-with-recent-glibc.patch
* Fri Jun  9 2017 ptesarik@suse.com
- Use the correct RPM Group for Python packages.
* Mon May 15 2017 ptesarik@suse.com
- upgrade to libkdumpfile-0.3.0
  * API and ABI changed (see NEWS)
  * Address translation routines moved into `libaddrxlat` (can be
    used without a dump file).
  * Python bindings.
  * Comprehensive test suite for `libaddrxlat`.
  * Caching.
  * ...and more!
* Mon Feb  1 2016 ptesarik@suse.com
- upgrade to libkdumpfile-0.2.0
  * API and ABI changed (see NEWS)
  * differentiation of Xen dump types (attribute "xen.type")
  * support for opening dumps in Xen hypervisor mode
  * many other Xen improvements
  * fix reading LKCD dump files
* Tue Dec  8 2015 ptesarik@suse.com
- upgrade to libkdumpfile-0.1.7
  * metadata is stored as hierarchical attributes which can be enumerated
- libkdumpfile-add-EM_AARCH64.patch: Dropped (now upstream).
- libkdumpfile-remove-ARCH_PPC64LE.patch: Dropped (now upstream).
- libkdumpfile-fallback-for-old-zlib.patch: Dropped (now upstream).
* Thu Nov 26 2015 ptesarik@suse.com
- Remove autoreconf invocation (fix build on SLE10).
* Wed Nov 25 2015 ptesarik@suse.com
- Add pkg-config to BuildRequires (adds back zlib support).
- libkdumpfile-fallback-for-old-zlib.patch: Fall back to
  AC_SEARCH_LIBS if there is no pkg-config file for zlib.
* Wed Nov 25 2015 ptesarik@suse.cz
- upgrade to libkdumpfile-0.1.5
  * Improved support of Xen dumpcore files.
  * Basic support for MIPS architecture.
  * Fix support for LKCD dumps on s390x.
- Add libkdumpfile.pc pkg-config file to -devel package.
- libkdumpfile-remove-ARCH_PPC64LE.patch: Fix build on ppc64le.
* Sat Aug 22 2015 jengelh@inai.de
- Set RPM group per standard practices. Update license field to
  actual conditions. Use original source URL.
* Fri Dec  5 2014 ptesarik@suse.cz
- upgrade to libkdumpfile-0.1.4
  * Improved error reporting.
  * Support of 32-bit x86 file format.
* Fri Nov  7 2014 ptesarik@suse.cz
- upgrade to libkdumpfile-0.1.3
  * Support of z/Architecture and S390 Dump file format.
* Mon Nov  3 2014 ptesarik@suse.cz
- Do not build static libraries.
* Sun Nov  2 2014 ptesarik@suse.cz
- Fix devel package dependencies.
* Sun Nov  2 2014 ptesarik@suse.cz
- Define %%make_install if not yet defined. This allows building
  the package on very old products (SLES10).
* Sat Nov  1 2014 ptesarik@suse.cz
- libkdumpfile-add-EM_AARCH64.patch: Add definition of EM_AARCH64
  if missing.
* Fri Oct 31 2014 ptesarik@suse.cz
- Make snappy support optional (fix build on products that do not
  have that library).
* Fri Oct 31 2014 ptesarik@suse.cz
- upgrade to libkdumpfile-0.1.2
- Drop libkdumpfile-fix-kdump_phys_base.patch: Upstream.
* Wed Oct 29 2014 ptesarik@suse.cz
- libkdumpfile-fix-kdump_phys_base.patch: Fix return type of
  kdump_phys_base() in definition.
* Wed Oct 29 2014 ptesarik@suse.cz
- Initial import.
